function DrawRange(X, C, M, W, Indices, PlotType, OwnWindow);
%DrawRange(X, C, M[, W[, Indices[, PlotType]]]);
% X       - Data, n rows of d dimensional vectors.
% C       - (k*d)*d matrix of k d*d covariance matrices.
% M       - k d-dimensional row vectors.
% W       - A vector of component weights.
% Indices - Vector containing the indices of components to draw.
% PlotType - If 1: use grayscale only, 2, 3: for screen-shots. Default is 0.
% OwnWindow - If non-zero, creates a new window. Default is 1.

if (nargin < 7)
    OwnWindow = 1;
end;
if (nargin < 6)
    PlotType = 0;
end;
if (nargin < 5) | isempty(Indices)
    Indices = 1:size(M, 1);
end;
if (nargin < 4) | isempty(W)
    W = ones(size(M, 1), 1);
else
    W = W ./ max(W);
end;

if (OwnWindow)
    figure;
    box on;
    pbaspect([1 1 1]);
end;
hold on;
if (PlotType == 3)
    plot(X(:,1), X(:,2), '.', 'markersize', 12, 'Color', [0.25 0.25 0.25]);
elseif (PlotType == 2)
    plot(X(:,1), X(:,2), '.', 'markersize', 12, 'Color', [0.5 0.5 0.5]);
elseif (PlotType == 1)
    plot(X(:,1), X(:,2), '.', 'markersize', 8, 'Color', [0.5 0.5 0.5]);
else
    plot(X(:,1), X(:,2), '.', 'markersize', 4, 'Color', [.5 .5 .5]);
end;
if (isempty(M))
    return;
end;
cov_Matrix = [];
for k = 1:length(Indices)
    j = Indices(k);
    if ~isempty(C)
        cov_Matrix = C(2*j-1:2*j,:);
    end;
    if (PlotType)
        Color = repmat([0.25 * (1 - W(j))], 1, 3);
        ellipse(cov_Matrix, M(j,:), 1, Color, 2);
    else
        ellipse(cov_Matrix, M(j,:), 1, [W(j), 0, 0.5 * (1 - W(j))]);
    end;
end;

function ellipse(A,m,radius,EllipseColor,LineWidth)
if ~isempty(A)
    p = 0;
    if A == A'
        [T,p] = chol(A);
        T = T';
    else
        %Q = A * A';
        T = A;
    end
    t = linspace(0,2*pi,100);

    if p == 0
        x = radius .* (T(1,1) .* cos(t) + T(1,2) .* sin(t)) + m(1,1);
        y = radius .* (T(2,1) .* cos(t) + T(2,2) .* sin(t)) + m(1,2);
        if (nargin < 5)
            plot(x, y, 'color', EllipseColor);
        else
            plot(x, y, 'color', EllipseColor, 'LineWidth', LineWidth);
        end;
    end;
end;
plot(m(1),m(2),'kx');
